@@ -181,18 +181,6 @@ static gdouble control_sample_uint32(const gpointer data, guint64 offset)
 }
 
 
-static gdouble control_sample_int64(const gpointer data, guint64 offset)
-{
-	return ABS(((const gint64 *) data)[offset]);
-}
-
-
-static gdouble control_sample_uint64(const gpointer data, guint64 offset)
-{
-	return ((const guint64 *) data)[offset];
-}
-
-
 static gdouble control_sample_float32(const gpointer data, guint64 offset)
 {
 	return fabsf(((const float *) data)[offset]);
@@ -679,9 +667,6 @@ static gboolean control_setcaps(GstPad *pad, GstCaps *caps)
 		case 32:
 			control_sample_func = is_signed ? control_sample_int32 : control_sample_uint32;
 			break;
-		case 64:
-			control_sample_func = is_signed ? control_sample_int64 : control_sample_uint64;
-			break;
 		default:
 			success = FALSE;
 			break;
@@ -1333,6 +1318,8 @@ static void gstlal_gate_class_init(GSTLALGateClass *klass)
 		"Kipp Cannon <kipp.cannon@ligo.org>, Chad Hanna <channa@ligo.caltech.edu>"
 	);
 
+	/* no 64-bit int support for control because cannot specify
+	 * threshold to that precision */
 	gst_element_class_add_pad_template(
 		element_class,
 		gst_pad_template_new(
@@ -1344,7 +1331,7 @@ static void gstlal_gate_class_init(GSTLALGateClass *klass)
 				"rate = (int) [1, MAX], " \
 				"channels = (int) 1, " \
 				"endianness = (int) BYTE_ORDER, " \
-				"width = (int) {8, 16, 32, 64}, " \
+				"width = (int) {8, 16, 32}, " \
 				"signed = (boolean) {true, false} ; " \
 				"audio/x-raw-float, " \
 				"rate = (int) [1, MAX], " \
