@@ -35,6 +35,9 @@
  * available.  This element monitors the data stream, watching timestamps
  * and offsets, and sets or clears the discontinuity flag on each buffer
  * based on exactly whether it is discontinuous with the previous buffer.
+ *
+ * Reviewed:  3d2cf9ea32085a2dd4854cb71b1cbaaf5547fc57 2014-08-12 K.
+ * Cannon, J.  Creighton, B. Sathyaprakash.
  */
 
 
@@ -278,15 +281,24 @@ static void finalize(GObject *object)
 
 
 /*
- * Base init function.  See
- *
- * http://developer.gnome.org/doc/API/2.0/gobject/gobject-Type-Information.html#GBaseInitFunc
+ * base_init()
  */
 
 
 static void base_init(gpointer class)
 {
-	GstElementClass *element_class = GST_ELEMENT_CLASS(class);
+}
+
+
+/*
+ * class_init()
+ */
+
+
+static void class_init(gpointer klass, gpointer class_data)
+{
+	GstElementClass *element_class = GST_ELEMENT_CLASS(klass);
+	GObjectClass *gobject_class = G_OBJECT_CLASS(klass);
 
 	gst_element_class_set_details_simple(
 		element_class,
@@ -296,6 +308,12 @@ static void base_init(gpointer class)
 		"Kipp Cannon <kipp.cannon@ligo.org>"
 	);
 
+	parent_class = g_type_class_ref(GST_TYPE_ELEMENT);
+
+	gobject_class->set_property = GST_DEBUG_FUNCPTR(set_property);
+	gobject_class->get_property = GST_DEBUG_FUNCPTR(get_property);
+	gobject_class->finalize = GST_DEBUG_FUNCPTR(finalize);
+
 	gst_element_class_add_pad_template(
 		element_class,
 		gst_pad_template_new(
@@ -318,25 +336,6 @@ static void base_init(gpointer class)
 			)
 		)
 	);
-}
-
-
-/*
- * Class init function.  See
- *
- * http://developer.gnome.org/doc/API/2.0/gobject/gobject-Type-Information.html#GClassInitFunc
- */
-
-
-static void class_init(gpointer klass, gpointer class_data)
-{
-	GObjectClass *gobject_class = G_OBJECT_CLASS(klass);
-
-	parent_class = g_type_class_ref(GST_TYPE_ELEMENT);
-
-	gobject_class->set_property = GST_DEBUG_FUNCPTR(set_property);
-	gobject_class->get_property = GST_DEBUG_FUNCPTR(get_property);
-	gobject_class->finalize = GST_DEBUG_FUNCPTR(finalize);
 
 	g_object_class_install_property(
 		gobject_class,
