@@ -57,14 +57,14 @@ struct _GSTLALShift {
 	GstPad *sinkpad;
 	GstPad *srcpad;
 
-	gint rate;
-	gint unit_size;
 	gint64 shift;
+	gboolean have_discont;
 };
 
 
 /**
  * GSTLALShiftClass:
+ * @parent_class:  the parent class
  */
 
 
