@@ -47,6 +47,23 @@ from gstlal import datasource
 #
 # A file that contains the multirate_datasource module code
 #
+# ###Review Status
+#
+# | Names                                          | Hash                                        | Date       |
+# | -------------------------------------------    | ------------------------------------------- | ---------- |
+# | Florent, Sathya, Duncan Me, Jolien, Kipp, Chad | 8a6ea41398be79c00bdc27456ddeb1b590b0f68e    | 2014-06-18 |
+#
+# #### Actions
+#
+# - Is the h(t) gate really necessary? It shouldn't really be used unless
+# there is something really wrong with the data. Wishlist: Tee off from 
+# the control panel and record on/off (This is already done).
+#
+# - Task for the review team: Check what data was analysed and how much
+# data was "lost" due to application of internal data quality.
+#
+# - There seems to be a bug in resampler (even) in the latest version of gstreamer; 
+# (produces one few sample). We need to better understand the consequence of this bug.
 
 ##
 # @package python.multirate_datasource
@@ -121,7 +138,7 @@ from gstlal import datasource
 #
 # }
 # @enddot
-def mkwhitened_multirate_src(pipeline, src, rates, instrument, psd = None, psd_fft_length = 8, ht_gate_threshold = None, veto_segments = None, seekevent = None, nxydump_segment = None, track_psd = False, block_duration = 1 * gst.SECOND, zero_pad = 0, width = 64, unit_normalize = True):
+def mkwhitened_multirate_src(pipeline, src, rates, instrument, psd = None, psd_fft_length = 8, ht_gate_threshold = float("inf"), veto_segments = None, seekevent = None, nxydump_segment = None, track_psd = False, block_duration = 1 * gst.SECOND, zero_pad = 0, width = 64, unit_normalize = True):
 	"""!
 	Build pipeline stage to whiten and downsample h(t).
 
@@ -177,23 +194,15 @@ def mkwhitened_multirate_src(pipeline, src, rates, instrument, psd = None, psd_f
 	head = pipeparts.mkaudioconvert(pipeline, head)
 	head = pipeparts.mkcapsfilter(pipeline, head, "audio/x-raw-float, width=%d, rate=%d, channels=1" % (width, max(rates)))
 
-	# export PSD in ascii text format
-	# FIXME:  also make them available in XML format as a single document
-	@bottle.route("/%s/psd.txt" % instrument)
-	def get_psd_txt(elem = whiten):
-		delta_f = elem.get_property("delta-f")
-		yield "# frequency\tspectral density\n"
-		for i, value in enumerate(elem.get_property("mean-psd")):
-			yield "%.16g %.16g\n" % (i * delta_f, value)	
 	if psd is None:
 		# use running average PSD
 		whiten.set_property("psd-mode", 0)
 	else:
-		# use running psd
 		if track_psd:
+			# use running average PSD
 			whiten.set_property("psd-mode", 0)
-		# use fixed PSD
 		else:
+			# use fixed PSD
 			whiten.set_property("psd-mode", 1)
 
 		#
@@ -222,6 +231,19 @@ def mkwhitened_multirate_src(pipeline, src, rates, instrument, psd = None, psd_f
 	if veto_segments is not None:
 		head = datasource.mksegmentsrcgate(pipeline, head, veto_segments, seekevent=seekevent, invert_output=True)
 
+	#
+	# optional gate on whitened h(t) amplitude.  attack and hold are
+	# made to be 1/4 second or 1 sample, whichever is larger
+	#
+
+	# FIXME:  this could be omitted if ht_gate_threshold is None, but
+	# we need to collect whitened h(t) segments, however something
+	# could be done to collect those if these gates aren't here.
+	ht_gate_window = max(max(rates) // 4, 1)	# samples
+	head = datasource.mkhtgate(pipeline, head, threshold = ht_gate_threshold if ht_gate_threshold is not None else float("+inf"), hold_length = ht_gate_window, attack_length = ht_gate_window, name = "%s_ht_gate" % instrument)
+	# emit signals so that a user can latch on to them
+	head.set_property("emit-signals", True)
+
 	#
 	# tee for highest sample rate stream
 	#
@@ -253,35 +275,20 @@ def mkwhitened_multirate_src(pipeline, src, rates, instrument, psd = None, psd_f
 	# adjust for the reduction in variance due to the downsampler.
 	#
 
-	# FIXME this for loop was reworked to allow the h(t) gate to go after
-	# audioresamplers.  There is apparently a cornercase in the
-	# audioresample element that is causing a problem
-	for rate in sorted(set(rates)):
-		if rate < max(rates): # downsample
-			# if requested make sure each output stream is unit
-			# normalized, otherwise the audio resampler removes
-			# power according to the rate difference and filter
-			# rolloff
-			if unit_normalize:
-				head[rate] = pipeparts.mkaudioamplify(pipeline, head[max(rates)], 1/math.sqrt(pipeparts.audioresample_variance_gain(quality, max(rates), rate)))
-			else:
-				head[rate] = head[max(rates)]
-			head[rate] = pipeparts.mkcapsfilter(pipeline, pipeparts.mkresample(pipeline, head[rate], quality = quality), caps = "audio/x-raw-float, rate=%d" % rate)
-			head[rate] = pipeparts.mknofakedisconts(pipeline, head[rate])	# FIXME:  remove when resampler is patched
-			head[rate] = pipeparts.mkchecktimestamps(pipeline, head[rate], "%s_timestamps_%d_whitehoft" % (instrument, rate))
+	for rate in sorted(set(rates))[:-1]:
+		# downsample. make sure each output stream is unit
+		# normalized, otherwise the audio resampler removes power
+		# according to the rate difference and filter rolloff
+		if unit_normalize:
+			head[rate] = pipeparts.mkaudioamplify(pipeline, head[max(rates)], 1. / math.sqrt(pipeparts.audioresample_variance_gain(quality, max(rates), rate)))
+		else:
+			head[rate] = head[max(rates)]
+		head[rate] = pipeparts.mkcapsfilter(pipeline, pipeparts.mkresample(pipeline, head[rate], quality = quality), caps = "audio/x-raw-float, rate=%d" % rate)
+		head[rate] = pipeparts.mknofakedisconts(pipeline, head[rate])	# FIXME:  remove when resampler is patched
+		head[rate] = pipeparts.mkchecktimestamps(pipeline, head[rate], "%s_timestamps_%d_whitehoft" % (instrument, rate))
 
-		#
-		# optional gate on whitened h(t) amplitude
-		#
-
-		if ht_gate_threshold is not None:
-			# all h(t) gates are controlled by the same max rate control input.
-			head[rate] = datasource.mkhtgate(pipeline, head[rate], control = pipeparts.mkqueue(pipeline, head[max(rates)], max_size_time = 0, max_size_bytes = 0, max_size_buffers = 0), threshold = ht_gate_threshold, hold_length = -rate // 4, attack_length = -rate // 4, name = "%s_%d_ht_gate" % (instrument, rate))
-
-			# emit signals so that a user can latch on to them
-			head[rate].set_property("emit-signals", True)
-	
 		head[rate] = pipeparts.mktee(pipeline, head[rate])
+
 	#
 	# done.  return value is a dictionary of tee elements indexed by
 	# sample rate
